embassy-stm32

Crates

git

Versions

stm32h7r3v8

Flavors

FMC

Struct FMC 

pub struct FMC { /* private fields */ }
FMC peripheral

Implementations

Source

impl FMC

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.